@@ -129,7 +129,7 @@ doImage1 dir theWikiUrl img
   = do return (getImagePage1 dir theWikiUrl (fst img, theName))
   where theName
           = case dropWhile (/= ':') (takeWhile (/= '|') (snd img)) of
-                (_ : xs) -> replace2 (replace2 xs "%27" "'") "%" "%25"
+                (_ : xs) -> replace2 xs "%27" "'"
                 _ -> []
 
 
@@ -142,7 +142,7 @@ doImage2 dir theWikiUrl img
            _ -> return Nothing
  where theName
           = case dropWhile (/= ':') (takeWhile (/= '|') (snd img)) of
-                (_ : xs) -> replace2 (replace2 xs "%27" "'") "%" "%25"
+                (_ : xs) -> replace2 xs "%27" "'"
                 _ -> []
 
 
