@@ -5,7 +5,7 @@ module UrlAnalyse
         FullWikiUrl, hostname, url, alternatives, lemma, wikiUrl, geturl,
         parses, geturl2, fullWikiUrlZero, getExpandedPage, getpage2, getBookpage)
        where
-import Network.HTTP.Conduit
+import Network.HTTP.Client
 import Data.ByteString.Lazy.Internal
 import Network.URL as URL
 import Control.Monad
@@ -25,7 +25,7 @@ import qualified Network.HTTP.Types as T
 import qualified Network.HTTP.Types.Version as V
 import Data.Serialize
 import GHC.Generics
-
+import Network.HTTP.Client.TLS
 deriving instance Read URL.URL
 deriving instance Read URL.Host
 deriving instance Read URL.Protocol
@@ -118,7 +118,7 @@ geturl u
  where  
         fun :: ErrorCall -> IO String
         fun _ = return ""
-        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Client.Response L.ByteString)
         statusExceptionHandler r _ = (return (I.Response {I.responseOriginalRequest=r, responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
  
 
@@ -142,7 +142,7 @@ geturl2 u
  where  
         fun :: ErrorCall -> IO BStr.ByteString
         fun _ = return (BStr.pack [])
-        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Client.Response L.ByteString)
         statusExceptionHandler r _ = (return (I.Response {I.responseOriginalRequest=r,responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
 
 {-DHUN| loads the wiki sourcecode strored under a lemma in on a server running mediawiki. The first parameter is the lemma to look up. The second parameter is the URL to the special:export page on the server. The return value is the source wikitext DHUN-}
@@ -167,7 +167,7 @@ geturl4 s u
  where  
         fun :: ErrorCall -> IO String
         fun _ = return ""
-        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Client.Response L.ByteString)
         statusExceptionHandler r _ = (return (I.Response {I.responseOriginalRequest=r,responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
 
 
@@ -192,7 +192,7 @@ geturl3 u d s
  where  
         fun :: ErrorCall -> IO String
         fun _ = return ""
-        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler ::  I.Request->SomeException -> IO (Network.HTTP.Client.Response L.ByteString)
         statusExceptionHandler r _ = (return (I.Response {I.responseOriginalRequest=r,responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
  
  
